pub struct Sanitizer { /* private fields */ }Expand description
Sanitizer for input text
Implementations
Sourceimpl Sanitizer
impl Sanitizer
Sourcepub fn with_allowed_chars(self, chars: &[char]) -> Self
pub fn with_allowed_chars(self, chars: &[char]) -> Self
Add additional allowed characters to the sanitizer
Sourcepub fn sanitize(&self, input: &str) -> SanitizeResult
pub fn sanitize(&self, input: &str) -> SanitizeResult
Sanitize the input text, ensuring it contains only allowed characters
Returns the sanitized string if successful, or an error message if invalid characters are found